Added dev- & canv- prefixes to Ganesh bounding boxes to indicate coordinate space

http://codereview.appspot.com/6457061/



git-svn-id: http://skia.googlecode.com/svn/trunk@4856 2bbb7eff-a529-9590-31e7-b0007b416f81
diff --git a/include/core/SkClipStack.h b/include/core/SkClipStack.h
index 60ed9ed..c0fadb1 100644
--- a/include/core/SkClipStack.h
+++ b/include/core/SkClipStack.h
@@ -51,13 +51,13 @@
     /**
      * getBounds places the current finite bound in its first parameter. In its
      * second, it indicates which kind of bound is being returned. If 
      * 'finiteBound' is a normal bounding box then it encloses all writeable
      * pixels. If 'finiteBound' is an inside out bounding box then it 
      * encloses all the un-writeable pixels and the true/normal bound is the
      * infinite plane. isIntersectionOfRects is an optional parameter
      * that is true if 'finiteBound' resulted from an intersection of rects.
      */
-    void getBounds(SkRect* finiteBound, 
+    void getBounds(SkRect* canvFiniteBound, 
                    BoundsType* boundType,
                    bool* isIntersectionOfRects = NULL) const;
 
@@ -188,7 +188,7 @@
                                int offsetY,
                                int maxWidth,
                                int maxHeight,
-                               SkRect* bounds,
+                               SkRect* devBounds,
                                bool* isIntersectionOfRects = NULL) const;
 
 private:
@@ -51,13 +51,13 @@
      * getBounds places the current finite bound in its first parameter. In its
      * second, it indicates which kind of bound is being returned. If 
-     * 'finiteBound' is a normal bounding box then it encloses all writeable
-     * pixels. If 'finiteBound' is an inside out bounding box then it 
+     * 'canvFiniteBound' is a normal bounding box then it encloses all writeable
+     * pixels. If 'canvFiniteBound' is an inside out bounding box then it 
      * encloses all the un-writeable pixels and the true/normal bound is the
      * infinite plane. isIntersectionOfRects is an optional parameter
@@ -51,13 +51,13 @@
      * encloses all the un-writeable pixels and the true/normal bound is the
      * infinite plane. isIntersectionOfRects is an optional parameter
-     * that is true if 'finiteBound' resulted from an intersection of rects.
+     * that is true if 'canvFiniteBound' resulted from an intersection of rects.
      */